boto v2.23.0 — boto v2.25.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »

# boto v2.23.0

date: | 2014/01/10

This release adds new pagination & date range filtering to Amazon Glacier, more support for selecting specific attributes within Amazon DynamoDB, security tokens from environment/config variables & many bugfixes/small improvements.

## Features

- Added pagination & date range filtering to Glacier inventory options. (issue 1977, commit 402a305)
- Added the ability to select the specific attributes to fetch in the `scan` & `get_item` calls within DynamoDB v2. (issue 1945, issue 1972, commit f6451fb & commit 96cd413)
- Allow getting a security token from either an environment or configuration variable. (:issue:`, :sha:`)
- Ported the `has_item` call from the original DynamoDB (v1) module to DynamoDB v2. (issue 1973, issue 1822, commit f96e9e3)
- Added an `associate_address_object` method to EC2. (issue 1967, issue 1874, issue 1893, commit dd6180c)
- Added a `download_to_fileobj` method to Glacier,similar to the S3 call of the same name. (issue 1960, issue 1941, commit 67266e5)
- Added support for arbitrary `dict` inputs to MWS. (issue 1966, commit 46f193f)

## Bugfixes

- Made the usage of `is/is not` more consistent. (issue 1930, commit 8597c54)

- Imported `with_statement` for old Python versions (issue 1975, commit a53a574)

- Changed the `Binary` data object within DynamoDB to throw an error if an invalid data type is used. (issue 1963, issue 1956, commit e5d30c8)

- Altered the integration tests to avoid connection errors to certain regions. (commit 2555b8a)

- Changed the GCS resumable upload handler to save tracker files with protection 0600. (commit 7cb344c)

- Documentation:

  > - Clarified documentation around the `list_metrics` call in CloudFormation. (issue 1962, commit c996a72)
  > - Added `Tag` to the Autoscale API docs. (issue 1964, commit 31118d9)
  > - Updated the AWS Support documentation to the latest. (commit 29f9264)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »